@@ -2,13 +2,13 @@
 
 # Build zipfiles for ATK on Win32
 
-ZIP=/tmp/atk-0.10-`date +%Y%m%d`.zip
-DEVZIP=/tmp/atk-dev-0.10-`date +%Y%m%d`.zip
-cd /opt/gnome-2.0
+ZIP=/tmp/atk-0.13-`date +%Y%m%d`.zip
+DEVZIP=/tmp/atk-dev-0.13-`date +%Y%m%d`.zip
+cd /opt/gnome2
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
-lib/libatk-10.dll
+lib/libatk-13.dll
 EOF
 
 rm $DEVZIP
